@@ -34,7 +34,7 @@ int cddb_handle_data( const char *data, char** artist, char** dtitle, char* titl
 
 	( *dtitle ) = NULL;
 
-	while ( *tmp != 0 ) { /* check against end of string */
+	while ( *tmp != 0 ) {	/* check against end of string */
 
 		/* get the row */
 		i = strcspn( tmp, "\r\n" );
@@ -46,7 +46,7 @@ int cddb_handle_data( const char *data, char** artist, char** dtitle, char* titl
 		tmp += i;
 
 		/* eval the row */
-		if ( strncmp( row, "TTITLE", 6 ) == 0 ) { /* Track TItle */
+		if ( strncmp( row, "TTITLE", 6 ) == 0 ) { /* Track Title */
 			/* get the track number before going on */
 			/* skip the TTITLE */
 			mark = row + 6;
@@ -88,29 +88,41 @@ int cddb_handle_data( const char *data, char** artist, char** dtitle, char* titl
 			i = strcspn( row, "=" ); i++;          /* skip to the data */
 			mark = row + i;
 
-			//j = strcspn( mark, "/" );		// dc: Breaks with slash in artist name IE 'AC/DC'
-			j = strstr( mark, " / " ) - mark + 1;	// dc: This will break if the artist contains ' / '
-			( *artist ) = ( char* ) malloc( j + 1 );
-			strncpy( ( *artist ), mark, j );
-			( *artist ) [ j ] = 0;
-			( *dtitle ) = ( char* ) malloc ( strlen( mark ) - j );
-			mark = mark + j + 1;
-			strcpy( ( *dtitle ), mark );
+			// tm:  hack around bogus CDDB entries
+			if (strstr(mark, " / ")) {
+				j = strstr( mark, " / " ) - mark + 1;
+				( *artist ) = ( char* ) malloc( j + 1 );
+				strncpy( ( *artist ), mark, j );
+				( *artist ) [ j ] = 0;
+				( *dtitle ) = ( char* ) malloc ( strlen( mark ) - j );
+				mark = mark + j + 1;
+				strcpy( ( *dtitle ), mark );
+			} else {
+#ifdef DEBUG
+				printf("malformed DTITLE, copying full DTITLE into both artist and dtitle\n");
+#endif
+				j = strlen(mark);
+				(* artist ) = (char* ) malloc (j + 1);
+				strncpy( ( *artist ), mark, j);
+				( *artist ) [ j ] = 0;
+				( *dtitle ) = (char* ) malloc (j + 1);
+				strncpy( ( *dtitle ), mark, j);
+				( *dtitle ) [ j ] = 0;
+			}
 
 			strip_trailing_space( artist );
 			strip_leading_space( artist );
 			strip_trailing_space( dtitle );
 			strip_leading_space( dtitle );
 			
-			
 			remove_non_unix_chars( *artist );
 			remove_non_unix_chars( *dtitle );
 			convert_slashes(*artist, '_'); // dc: _ Artist, - others
 			convert_slashes(*dtitle, '-');
-		        if ( config.cddb_config.convert_spaces == TRUE ) {
-			    convert_spaces( *artist, '_' );
-		            convert_spaces( *dtitle, '_' );
-		        }
+			if ( config.cddb_config.convert_spaces == TRUE ) {
+				convert_spaces( *artist, '_' );
+				convert_spaces( *dtitle, '_' );
+			}
 #ifdef DEBUG
 			printf( "Artist: %s\n", ( *artist ) );
 			printf( "Dtitle: %s\n", ( *dtitle ) );
@@ -149,7 +161,6 @@ int do_cddb( char** result, char **disc_category, int tracknum, int duration, lo
 	char **category = NULL, **title = NULL, **alt_id = NULL;
 
 	char *final_cat, *final_id, *cd_id, *uri, *wwwserver;
-	unsigned long int id;
 
 	/* chop up the URL */
 	wwwserver = uri = strdup( server );
@@ -158,9 +169,7 @@ int do_cddb( char** result, char **disc_category, int tracknum, int duration, lo
 	final_cat = ( char* ) malloc( 20 );
 	final_id = ( char* ) malloc( 20 );
 	cd_id = ( char* ) malloc( 20 );
-
-	id = cddb_disk_id( duration, tracknum, offset );
-	sprintf( cd_id, "%08lx", id );
+	sprintf( cd_id, "%08lx", cddb_disk_id( duration, tracknum, offset ) );
 
 	if ( proto == CDDBP ) {
 		sock = socket_init( wwwserver, port );
@@ -281,19 +290,18 @@ int read_local_file ( char** result, int tracknum, int duration, long int offset
 #ifdef DEBUG
 	printf( "cddb_disk_id returned '%s'\n", cd_id );
 #endif
-	/*
-	   		first, check the directory pointed to by the config file
-	   	*/
-	strcpy( file_check, config.cddb_path );        	/*   start with the base path  */
+	/* first, check the directory pointed to by the config file */
+	strcpy( file_check, config.cddb_path );		/* start with the base path */
 	strcat( file_check, "/" );
-	strcat( file_check, cd_id );        		/*   add the filename  */
+	strcat( file_check, cd_id );				/* add the filename */
 	if ( ( datafile = fopen( file_check, "r" ) ) == NULL ) {
-		/*
-		   			since the file didn't exist in the directory
-		   			check the category sub-directories
-		   		*/
+		/*  
+		 *  since the file didn't exist in the directory
+		 * 	check the category sub-directories
+		 */
 		for ( i = 0; cddb_categories[ i ].cddb_name != NULL; i++ ) {
-			strcpy( file_check, config.cddb_path ); 			/*   start with the base path  */
+			strcpy( file_check, config.cddb_path ); 	/*   start with the base path  */
+			strcat( file_check, "/" ); 					/*   add the seperator  */
 			strcat( file_check, cddb_categories[ i ].cddb_name ); 	/*   add the catagory  */
 			strcat( file_check, "/" ); 					/*   add the seperator  */
 			strcat( file_check, cd_id ); 				/*   add the filename  */
@@ -315,9 +323,7 @@ int do_cddb_proxy( char** result, char **disc_category, int tracknum, int durati
 	FILE * sock = NULL;
 	int status, matches, i;
 	char **category = NULL, **title = NULL, **alt_id = NULL;
-
 	char *final_cat, *final_id, *cd_id, *uri, *wwwserver;
-	unsigned long int id;
 
 	/* chop up the URL */
 	wwwserver = uri = strdup( server );
@@ -327,9 +333,7 @@ int do_cddb_proxy( char** result, char **disc_category, int tracknum, int durati
 	final_id = ( char* ) malloc( 20 );
 	cd_id = ( char* ) malloc( 20 );
 
-	id = cddb_disk_id( duration, tracknum, offset );
-	sprintf( cd_id, "%08lx", id );
-
+	sprintf( cd_id, "%08lx", cddb_disk_id( duration, tracknum, offset ) );
 	if ( proto == CDDBP ) {
 		sock = socket_init( wwwserver, port );
 		if ( !sock )
@@ -338,7 +342,7 @@ int do_cddb_proxy( char** result, char **disc_category, int tracknum, int durati
 		/* connect to the cddb server */
 		status = cddbp_signon( sock );
 		switch ( status ) {
-	case 200 : case 201 : break;         	/* might want to differenciate when write() is supported on the server side */
+	case 200 : case 201 : break;         	/* might want to differentiate when write() is supported on the server side */
 case 432 : case 433 : case 434 :
 			fclose( sock ); return CONNECT_REFUSED;
 		default :
@@ -453,24 +457,20 @@ int cddb_main( _main_data *main_data )
 		else
 			strcpy( main_data->disc_artist, artist );
 		free( artist );
-
 		if ( dtitle == 0 )
 			strcpy( main_data->disc_title, "" );
 		else
 			strcpy( main_data->disc_title, dtitle );
 		free( dtitle );
-
 		if ( category == 0 )
 			strcpy( main_data->disc_category, "" );
 		else
 			strcpy( main_data->disc_category, category );
 		free( category );
-
 		for ( i = 0; i < tracknum; i++ )     /* fixed a sneaky bug here */
 		{
 			/* copy the data into the main_data structure */
 			put_track_title(titles[i], main_data, i);
-
 			free( titles[ i ] );
 		}
 		/* this is needed to update the display with the new data */
