@@ -18,7 +18,7 @@
 
 #include "err_dialog_handler.h"
 
-#define VERSION		"2.6.1"
+#define VERSION		"2.6.4"
 
 #ifndef TRUE
 #define TRUE		1
@@ -56,6 +56,10 @@
 #define OGG                         3
 #define FLAC			    		4
 
+#define MIN_NICE_LEVEL         19
+#define MAX_NICE_LEVEL         0
+
+
 /* =====================================================
  * Structures
  * ===================================================*/
@@ -85,6 +89,7 @@ typedef struct {
 		char plugin[ MAX_COMMAND_LENGTH ];
 		int bitrate;
 		int use_varbitrate;
+		int priority;
 		int use_high_qual;
 		int use_crc;
 		int vbr_qual;
