@@ -71,6 +71,8 @@ static struct {
       INT, 0, "1" },
     { "Encoder::VBRQual", &config.encoder.vbr_qual,
       INT, 0, "4" },
+	{ "Encoder::Priority", &config.encoder.priority,
+	  INT, 0, "10" },
     { "Encoder::HighQual", &config.encoder.use_high_qual,
       INT, 0, "1" },
     { "Encoder::useCRC", &config.encoder.use_crc,
