@@ -372,7 +372,9 @@ int cw_mp3_handler( int ops, _main_data *main_data, GtkWidget *notebook )
 	static int num_bitrates, num_plugins;
 	static GtkWidget *use_varbitrate_ckbx, *use_high_qual_ckbx, *use_crc_ckbx;
 	static GtkObject *vbr_qual_adj;
+	static GtkObject *pri_adj;
 	static GtkWidget *vbr_qual_scale;
+	static GtkWidget *pri_scale;
 
 	static struct {
 		GtkWidget *menu_item;
@@ -385,6 +387,7 @@ int cw_mp3_handler( int ops, _main_data *main_data, GtkWidget *notebook )
 		char *high_qual_op;
 		char *crc_op;
 	} plugins[] = {
+ 		{ NULL, "toolame", "ripperX_plugin-toolame", "toolame layer 2 encoder", "-b", "", "-v", "", "-e"},
  		{ NULL, "encode ", "ripperX_plugin-encode", "ISO Encoder v2", "-b", "", "", "", "-e"},
  		{ NULL, "8hz-mp3 ", "ripperX_plugin-8hz-mp3", "8hz-mp3 Encoder", "-b", "", "", "", ""},
  		{ NULL, "lame", "ripperX_plugin-lame", "Lame MP3 Encoder", "-b", "--nohist -v", "-V", "-h", "-p"},
@@ -401,21 +404,25 @@ int cw_mp3_handler( int ops, _main_data *main_data, GtkWidget *notebook )
 		GtkWidget *button;
 		int bitrate;
 	} bitrate[] = {
-
+	    { NULL, 32 },
+	    { NULL, 40 },
+	    { NULL, 48 },
 	    { NULL, 56 },
 	    { NULL, 64 },
+	    { NULL, 80 },
 	    { NULL, 96 },
 	    { NULL, 112 },
 	    { NULL, 128 },          /* Default */
 	    { NULL, 160 },
 	    { NULL, 192 },
+	    { NULL, 224 },
 	    { NULL, 256 },
 	    { NULL, 320 }
 	};
 
 	switch ( ops ) {
 	case WIDGET_CREATE : {
-			GtkWidget * frame, *table, *vbox, *vbox2, *hbox, *label, *label2;
+			GtkWidget * frame, *table, *vbox, *vbox2, *vbox3, *hbox, *label, *label2;
 			int i, match;
 			char buf[ 5 ];
 
@@ -509,6 +516,20 @@ int cw_mp3_handler( int ops, _main_data *main_data, GtkWidget *notebook )
 			label = gtk_label_new ("0=high quality and bigger files, 9=smaller files");
 			gtk_container_add (GTK_CONTAINER (vbox2), label);
 
+			/* encoder priority */
+			frame = gtk_frame_new ("Encoder Priority");
+			gtk_container_add (GTK_CONTAINER (vbox), frame);
+			vbox3 = gtk_vbox_new (FALSE, 3);
+			gtk_container_border_width (GTK_CONTAINER(vbox3), 5);
+			gtk_container_add (GTK_CONTAINER (frame), vbox3);
+
+			pri_adj = gtk_adjustment_new ((gfloat) CLAMP (config.encoder.priority, MAX_NICE_LEVEL, MIN_NICE_LEVEL), 0.0, 19.0, 1.0, 1.0, 0.0);
+			pri_scale = gtk_hscale_new (GTK_ADJUSTMENT (pri_adj));
+			gtk_scale_set_digits (GTK_SCALE (pri_scale), 0);
+			gtk_container_add (GTK_CONTAINER (vbox3), pri_scale);
+			label = gtk_label_new ("0=high priority, 19=system is responsive while encoding");
+			gtk_container_add (GTK_CONTAINER (vbox3), label);
+
 			/* High Quality */
 			use_high_qual_ckbx = gtk_check_button_new_with_label( "High quality mode" );
 			gtk_toggle_button_set_state( GTK_TOGGLE_BUTTON( use_high_qual_ckbx ),
@@ -528,8 +549,7 @@ int cw_mp3_handler( int ops, _main_data *main_data, GtkWidget *notebook )
 			label = gtk_label_new( "Extra Options: " );
 			gtk_box_pack_start( GTK_BOX( hbox ), label, FALSE, FALSE, 0 );
 
-			extra_options_entry = gtk_entry_new_with_max_length( MAX_OPTIONS_LENGTH
-			                      - 20 );
+			extra_options_entry = gtk_entry_new_with_max_length( MAX_OPTIONS_LENGTH - 20 );
 			gtk_entry_set_text( GTK_ENTRY( extra_options_entry ),
 			                    config.encoder.extra_options );
 
