@@ -67,9 +67,9 @@ int find_next_job( _main_data *main_data,
 /* This function finds what to do next. type is WAV or MP3.
  * It returns -1 when there's no job left, 0 when a job's found */
 
-int job_controller_timeout( gpointer data );
-/* data will be casted to int and used as ops */
-
+void job_controller_timeout_start();
+int job_controller_timeout_update( gpointer anything);
+void job_controller_timeout_stop();
 
 void calc_stat( _main_data *main_data, _stat *stat,
                 unsigned current, int cur_track, int cur_type, int ops )
@@ -539,31 +539,28 @@ int find_next_job( _main_data *main_data,
 	return 0;
 }
 
-int job_controller_timeout( gpointer data )
+
+static int timer;
+
+void job_controller_timeout_start()
 {
-	int ops;
-	static int timer;
-
-	ops = ( int ) data;
-
-	switch ( ops ) {
-	case JC_T_START :
-		timer = gtk_timeout_add( JC_TIMEOUT,
-		                         job_controller_timeout, ( gpointer ) JC_T_UPDATE );
-		return TRUE;
-
-	case JC_T_UPDATE :
-		job_controller( JC_UPDATE, NULL );
-		return TRUE;
-
-	case JC_T_STOP :
-		gtk_timeout_remove( timer );
-		return TRUE;
-	}
-	/* Just to avoid warning msg */
-	return FALSE;
+	timer = gtk_timeout_add( JC_TIMEOUT, job_controller_timeout_update, NULL);
 }
 
+
+int job_controller_timeout_update( gpointer anything)
+{
+	job_controller( JC_UPDATE, NULL );
+	return TRUE;
+}
+
+
+void job_controller_timeout_stop()
+{
+	gtk_timeout_remove( timer );
+}
+
+
 void job_controller( int ops, _main_data *main_data )
 {
 	static int cur_type = -1;
@@ -663,7 +660,7 @@ void job_controller( int ops, _main_data *main_data )
 		/* Create wav/mp3 status frame */
 		wm_status_frame_handler( WIDGET_CREATE, cur_type, &stat, NULL );
 
-		job_controller_timeout( JC_T_START );
+		job_controller_timeout_start();
 		return;
 
 	case JC_UPDATE :
@@ -699,7 +696,7 @@ void job_controller( int ops, _main_data *main_data )
 						err_handler( PLUGIN_NOT_PRESENT_ERR,
 						             "Maybe ripperX has failed to execute the plugin" );
 						wav_pi_pid = -1;
-						job_controller_timeout( ( gpointer ) JC_T_STOP );
+						job_controller_timeout_stop();
 						job_controller( JC_ABORT_ALL_DELETE, main_data );
 						return;
 					}
@@ -739,7 +736,7 @@ void job_controller( int ops, _main_data *main_data )
 							calc_stat( main_data, &stat, wav_current,
 							           temp_track, WAV, CALC_STOP_SESSION );
 
-							job_controller_timeout( ( gpointer ) JC_T_STOP );
+							job_controller_timeout_stop();
 							job_finisher( main_data );
 							return;
 						}
@@ -765,7 +762,7 @@ void job_controller( int ops, _main_data *main_data )
 							                             &wav_read_fd ) < 0 ) {
 							calc_stat( main_data, &stat, wav_current,
 							           wav_cur_track, WAV, CALC_STOP_SESSION );
-							job_controller_timeout( ( gpointer ) JC_T_STOP );
+							job_controller_timeout_stop();
 							job_finisher( main_data );
 							return;
 						}
@@ -805,7 +802,7 @@ void job_controller( int ops, _main_data *main_data )
 						err_handler( PLUGIN_NOT_PRESENT_ERR,
 						             "Maybe ripperX has failed to execute the plugin" );
 						mp3_pi_pid = -1;
-						job_controller_timeout( ( gpointer ) JC_T_STOP );
+						job_controller_timeout_stop();
 						job_controller( JC_ABORT_ALL_DELETE, main_data );
 						return;
 					}
@@ -854,7 +851,7 @@ void job_controller( int ops, _main_data *main_data )
 						cur_type = -1;
 						calc_stat( main_data, &stat, mp3_current,
 						           temp_track, MP3, CALC_STOP_SESSION );
-						job_controller_timeout( ( gpointer ) JC_T_STOP );
+						job_controller_timeout_stop();
 						stat.encoding = FALSE;
 
 						job_finisher( main_data );
@@ -894,7 +891,7 @@ void job_controller( int ops, _main_data *main_data )
 			{
 				calc_stat( main_data, &stat, mp3_current,
 						   mp3_cur_track, MP3, CALC_STOP_SESSION );
-				job_controller_timeout( ( gpointer ) JC_T_STOP );
+				job_controller_timeout_stop();
 				job_finisher( main_data );
 			}
 			stat.encoding = TRUE;
@@ -920,7 +917,7 @@ void job_controller( int ops, _main_data *main_data )
 
 		calc_stat( main_data, &stat, wav_current,
 		           wav_cur_track, WAV, CALC_PAUSE );
-		job_controller_timeout( ( gpointer ) JC_T_STOP );
+		job_controller_timeout_stop();
 		return;
 
 	case JC_CONT :
@@ -941,7 +938,7 @@ void job_controller( int ops, _main_data *main_data )
 
 		calc_stat( main_data, &stat, wav_current,
 		           wav_cur_track, cur_type, CALC_CONT );
-		job_controller_timeout( ( gpointer ) JC_T_START );
+		job_controller_timeout_start();
 		return;
 
 	case JC_ABORT :
@@ -1010,7 +1007,7 @@ void job_controller( int ops, _main_data *main_data )
 		cur_type = -1;
 		calc_stat( main_data, &stat, wav_current,
 		           wav_cur_track, cur_type, CALC_STOP_SESSION );
-		job_controller_timeout( ( gpointer ) JC_T_STOP );
+		job_controller_timeout_stop();
 		job_finisher( main_data );
 		return;
 	}
