@@ -685,8 +685,7 @@ long check_free_space(char* dir) {
     char cmd[MAX_FILE_NAME_LENGTH];
     char buffer[MAX_FILE_NAME_LENGTH];
     
-    snprintf(cmd, MAX_FILE_NAME_LENGTH - 1, 
-             "df -k '%s' |awk '{print $3}'", dir);
+    snprintf(cmd, MAX_FILE_NAME_LENGTH - 1, "df -k '%s' |awk '{print $4}'", dir);
     file = popen(cmd, "r");
     fscanf(file, "%s\n", &buffer); /* read the Available title */
     fscanf(file, "%ld", &len); /* now read the length */
@@ -881,7 +880,7 @@ void put_track_title(char *src, _main_data *main_data, int tno)
 		;
 
 	memcpy(tk_p->title, sp, ep - sp + 1);
-	tk_p->title[ep - sp + 1];
+	tk_p->title[ep - sp + 1] = 0;
 }
 
 /* dup_str - return a copy of a string in allocated memory */
