@@ -1,5 +1,6 @@
 
 #include <stdio.h>
+#include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
 #include <sys/types.h>
@@ -29,13 +30,12 @@ int process_cd_contents_output( _main_data *main_data, int pipe_fd );
 
 int execute_ripper_encoder_with_plugin( char *pg_com,
                                         char *pi_com,
-                                        int *program_pid, int *plugin_pid,
+                                        int *program_pid, 
+										int *plugin_pid,
                                         int *read_fd );
 
 int parse_plugin_output( char *out, double *progress, char *msg );
 
-
-
 int process_cd_contents_output( _main_data *main_data, int fd )
 {
 	FILE * stream;
@@ -188,11 +188,9 @@ int scan_cd( _main_data *main_data )
 	return return_value;
 }
 
-int start_ripping_encoding( int type, int begin, int length,
-                            int track,
+int start_ripping_encoding( int type, int begin, int length, int track,
                             char *wav_file_name, char *mp3_file_name,
-                            int *program_pid, int *plugin_pid,
-                            int *read_fd )
+                            int *program_pid, int *plugin_pid, int *read_fd )
 {
 	char * tmp;
 	char plugin[ MAX_COMMAND_LENGTH ];
@@ -202,7 +200,7 @@ int start_ripping_encoding( int type, int begin, int length,
 	// <tmancill@debian.org>
 	char debian_path[ MAX_COMMAND_LENGTH ];
 	strcpy(debian_path, "/usr/lib/ripperx:");
-	strcat(debian_path, (char *) getenv("PATH"));
+	strcat(debian_path, getenv("PATH"));
 	setenv("PATH", debian_path, 1);
 	// end Debian modifications
 
@@ -210,15 +208,19 @@ int start_ripping_encoding( int type, int begin, int length,
 	if ( type == WAV ) {
 		snprintf( command, sizeof( command ), "%s %d '%s'", config.ripper.ripper, track + 1, wav_file_name );
 	} else {
-		// nasty ugly hack to support a REALLY stupid interface for mp3enc
+		// hack to support the interface for mp3enc
 		if ( !strcmp( config.encoder.encoder, "mp3enc" ) )
-			snprintf( command, sizeof( command ), "%s -v -if '%s' -of '%s'", config.encoder.full_command, wav_file_name, mp3_file_name );
-                else if ( !strcmp( config.encoder.encoder, "flac" ) )
-			snprintf( command, sizeof( command ), "%s -o '%s' '%s'", config.encoder.full_command, mp3_file_name, wav_file_name );
-                else if ( !strcmp( config.encoder.encoder, "oggenc" ) )
-			snprintf( command, sizeof( command ), "%s -o '%s' '%s'", config.encoder.full_command, mp3_file_name, wav_file_name );
+			snprintf( command, sizeof( command ), "nice -n %i %s -v -if '%s' -of '%s'", 
+					config.encoder.priority, config.encoder.full_command, wav_file_name, mp3_file_name );
+		else if ( !strcmp( config.encoder.encoder, "flac" ) )
+			snprintf( command, sizeof( command ), "nice -n %i %s -o '%s' '%s'", 
+					config.encoder.priority, config.encoder.full_command, mp3_file_name, wav_file_name );
+		else if ( !strcmp( config.encoder.encoder, "oggenc" ) )
+			snprintf( command, sizeof( command ), "nice -n %i %s -o '%s' '%s'",
+					config.encoder.priority, config.encoder.full_command, mp3_file_name, wav_file_name );
 		else
-			snprintf( command, sizeof( command ), "%s '%s' '%s'", config.encoder.full_command, wav_file_name, mp3_file_name );
+			snprintf( command, sizeof( command ), "nice -n %i %s '%s' '%s'",
+					config.encoder.priority, config.encoder.full_command, wav_file_name, mp3_file_name );
 	}
 
 	// parse/expand plugin command
@@ -231,9 +233,7 @@ int start_ripping_encoding( int type, int begin, int length,
 	snprintf( plugin, sizeof( plugin ), "%s %d %d", tmp, begin, length );
 
 	// execute
-	if ( execute_ripper_encoder_with_plugin( command, plugin,
-		        program_pid, plugin_pid,
-		        read_fd ) < 0 )
+	if ( execute_ripper_encoder_with_plugin( command, plugin, program_pid, plugin_pid, read_fd ) < 0 )
 		return - 1;
 
 	return 0;
