@@ -29,7 +29,7 @@ void sf_track_selected_button_toggled( GtkWidget *widget, gpointer callback_data
 {
 	int track;
 
-	track = ( int ) callback_data;
+	track = *( int * ) callback_data;
 	select_frame_handler( SF_SELECT_BUTTON_ACT, track, NULL );
 }
 
@@ -47,7 +47,7 @@ void sf_filename_entry_changed( GtkWidget *widget, gpointer callback_data )
 {
 	int track;
 
-	track = ( int ) callback_data;
+	track = *( int * ) callback_data;
 	select_frame_handler( SF_FILENAME_ENTRY_CHG, track, NULL );
 }
 
@@ -59,7 +59,7 @@ void sf_cd_play_button_clicked( GtkWidget *widget, gpointer callback_data )
 	play_cd_wav_mp3( STOP, WAV, NULL );
 	play_cd_wav_mp3( STOP, MP3, NULL );
 
-	snprintf( buf, sizeof( buf ), "%d", ( int ) callback_data + 1 );
+	snprintf( buf, sizeof( buf ), "%d", ( *( int * ) callback_data ) + 1 );
 	play_cd_wav_mp3( PLAY, CD, buf );
 }
 
@@ -85,6 +85,7 @@ void select_frame_handler( int ops, int track, _main_data *main_data )
 	static GtkWidget *rip_action_button = NULL;
 	static GtkWidget *encode_action_button = NULL;
 	static char saved_filename_entry[ MAX_NUM_TRACK ][ MAX_FILE_NAME_LENGTH ];
+	static int track_numbers[ MAX_NUM_TRACK ];
 	static _main_data *saved_main_data;
 	static int num_tracks, button_state;
 	GtkWidget *pixmap;
@@ -170,12 +171,12 @@ void select_frame_handler( int ops, int track, _main_data *main_data )
 			gtk_container_border_width( GTK_CONTAINER( hbox1 ), 5 );
 			gtk_box_pack_start( GTK_BOX( hbox ), hbox1 , FALSE, FALSE, 0 );
 
-			rip_action_button = gtk_radio_button_new_with_label( NULL, "Rip wav" );
+			rip_action_button = gtk_radio_button_new_with_label( NULL, "Rip to WAV" );
 			gtk_toggle_button_set_state( GTK_TOGGLE_BUTTON( rip_action_button ), 0 );
 			gtk_box_pack_start( GTK_BOX( hbox1 ), rip_action_button, FALSE, FALSE, 0 );
 
 			encode_action_button = gtk_radio_button_new_with_label(
-			                           gtk_radio_button_group( GTK_RADIO_BUTTON( rip_action_button ) ), "Encode mp3" );
+			                           gtk_radio_button_group( GTK_RADIO_BUTTON( rip_action_button ) ), "Encode" );
 			gtk_toggle_button_set_state( GTK_TOGGLE_BUTTON( encode_action_button ), 1 );
 			gtk_box_pack_start( GTK_BOX( hbox1 ), encode_action_button, FALSE, FALSE, 0 );
 
@@ -227,6 +228,7 @@ void select_frame_handler( int ops, int track, _main_data *main_data )
 			}
 
 			for ( i = 0; i < num_tracks; i++ ) {
+				track_numbers[ i ] = i;
 				if ( strlen ( saved_filename_entry[ i ] ) == 0 ) {
 					get_track_title(saved_filename_entry[i], main_data, i);
 				}
@@ -240,7 +242,7 @@ void select_frame_handler( int ops, int track, _main_data *main_data )
 
 				gtk_signal_connect( GTK_OBJECT( button ), "clicked",
 				                    GTK_SIGNAL_FUNC( sf_cd_play_button_clicked ),
-				                    ( gpointer ) i );
+				                    &track_numbers[ i ] );
 				gtk_table_attach( GTK_TABLE( table ), button, 0, 1, i, i + 1,
 				                  0, GTK_EXPAND | GTK_FILL, 0, 0 );
 
@@ -274,10 +276,10 @@ void select_frame_handler( int ops, int track, _main_data *main_data )
 
 				gtk_signal_connect( GTK_OBJECT( track_selected_button[ i ] ), "clicked",
 				                    GTK_SIGNAL_FUNC( sf_track_selected_button_toggled ),
-				                    ( gpointer ) i );
+				                    &track_numbers[ i ] );
 				gtk_signal_connect( GTK_OBJECT( filename_entry[ i ] ), "changed",
 				                    GTK_SIGNAL_FUNC( sf_filename_entry_changed ),
-				                    ( gpointer ) i );
+				                    &track_numbers[ i ] );
 			}
 			gtk_widget_show_all( vbox );
 			return;
