@@ -17,7 +17,7 @@
 
 void time_status_frame_handler( int ops, GtkWidget *time_frame, _stat *stat );
 
-/* Callback data will be casted to int, and will be used as type */
+/* Callback data is a pinter to the int type */
 void wms_p_c_button_clicked( GtkWidget *widget, gpointer callback_data );
 void wms_abort_button_clicked( GtkWidget *widget, gpointer callback_data );
 void wms_abort_all_button_clicked( GtkWidget *widget, gpointer callback_data );
@@ -102,17 +102,17 @@ void time_status_frame_handler( int ops, GtkWidget *time_frame, _stat *stat )
 	}
 }
 
-/* Callback data is type */
+/* Callback data is pointer to type */
 
 void wms_p_c_button_clicked( GtkWidget *widget, gpointer callback_data )
 {
-	wm_status_frame_handler( WMS_P_C_BUTTON_ACT, ( int ) callback_data,
+	wm_status_frame_handler( WMS_P_C_BUTTON_ACT, *( int *) callback_data,
 	                         NULL, NULL );
 }
 
 void wms_abort_button_clicked( GtkWidget *widget, gpointer callback_data )
 {
-	wm_status_frame_handler( WMS_ABORT_BUTTON_ACT, ( int ) callback_data,
+	wm_status_frame_handler( WMS_ABORT_BUTTON_ACT, *( int *) callback_data,
 	                         NULL, NULL );
 }
 
@@ -232,7 +232,7 @@ void wm_status_frame_handler( int ops, int type,
 			gtk_widget_set_usize( button, 80, 0 );
 			gtk_signal_connect ( GTK_OBJECT ( button ), "clicked",
 			                     GTK_SIGNAL_FUNC ( wms_abort_button_clicked ),
-			                     ( gpointer ) type );
+			                     &type );
 			gtk_box_pack_end( GTK_BOX( temp_hbox ), button, FALSE, FALSE, 0 );
 
 			/* Pause continue button */
@@ -243,7 +243,7 @@ void wm_status_frame_handler( int ops, int type,
 			gtk_container_add( GTK_CONTAINER( p_c_button ), pause_label );
 			gtk_signal_connect ( GTK_OBJECT ( p_c_button ), "clicked",
 			                     GTK_SIGNAL_FUNC ( wms_p_c_button_clicked ),
-			                     ( gpointer ) type );
+			                     &type );
 			gtk_box_pack_end( GTK_BOX( temp_hbox ), p_c_button, FALSE, FALSE, 0 );
 			gtk_widget_grab_default( p_c_button );
 
